import { useAjax } from '@/Hook/useAjax';
import {
  apibookCategoryAdd,
  apibookCategoryDel,
  apibookCategoryEdit,
  apibookCategoryList,
  apibookCategorySort,
} from '@/services/book/classifyList';
import { PlusCircleOutlined } from '@ant-design/icons';
import {
  ActionType,
  BetaSchemaForm,
  PageContainer,
  ProFormInstance,
  ProTable,
} from '@ant-design/pro-components';
import { useModel } from '@umijs/max';
import { Button, message } from 'antd';
import { useRef, useState } from 'react';
import formConfig from './formConfig';
import { columns } from './tableConfig';

type DataItem = {
  name: string;
  state: string;
};
const Page: React.FC = () => {
  const formRef = useRef<ProFormInstance>();
  const actionRef = useRef<ActionType>();
  let { state } = useModel('global');
  let [open, setOpen] = useState<any>(null); //新增作者
  let [editValues, setEditValues] = useState<any>({});
  let bookCategoryList = useAjax((params) => apibookCategoryList(params), { type: 'table' });
  let bookCategorySort = useAjax((params) => apibookCategorySort(params));
  let bookCategoryEdit = useAjax((params) => apibookCategoryEdit(params));
  let bookCategoryAdd = useAjax((params) => apibookCategoryAdd(params));
  let bookCategoryDel = useAjax((params) => apibookCategoryDel(params));
  // 编辑
  const edit = (item: any) => {
    setEditValues(item);
    setTimeout(() => {
      formRef?.current?.setFieldsValue({ ...item });
    }, 100);
    setOpen(true);
  };
  // 删除
  const del = (id: any) => {
    bookCategoryDel.run(id).then((res) => {
      if (res.code === 200) {
        actionRef?.current?.reload();
        message.success('删除成功');
      }
    });
  };
  // 新增 or 编辑
  const submit = async (values: any) => {
    let api = editValues?.id ? bookCategoryEdit : bookCategoryAdd;
    if (editValues?.id) {
      values.id = editValues?.id;
    }
    api.run(values).then((res) => {
      if (res.code === 200) {
        actionRef?.current?.reload();
        message.success('操作成功!');
        closeForm(false);
      }
    });
    console.log(values);
  };
  // 关闭表单弹窗和重置表单内容
  const closeForm = (b: boolean, values?: any) => {
    if (!b) {
      setEditValues({});
      formRef?.current?.resetFields?.();
      setOpen(b);
    } else {
    }
  };
  // 排序
  const sort = (params: any) => {
    return bookCategorySort
      .run(params)
      .then((res: any) => {
        if (!res?.code) {
          return false;
        } else {
          actionRef?.current?.reload();
          message.success('修改排序成功');
          return true;
        }
      })
      .catch((err: any) => {
        return false;
      });
  };
  return (
    <PageContainer>
      <ProTable<any, any>
        headerTitle={'分类列表'}
        actionRef={actionRef}
        rowKey={(r) => r.id}
        search={{
          labelWidth: 120,
        }}
        scroll={{ x: 'auto' }}
        request={async (params) => {
          return await bookCategoryList.run(params);
        }}
        toolBarRender={() => {
          return [
            <Button
              type="primary"
              onClick={() => {
                setOpen(true);
              }}
            >
              <PlusCircleOutlined />
              新增分类
            </Button>,
          ];
        }}
        columns={columns({ edit, del, enumList: state?.enumList, sort })}
        // bordered
      />
      <BetaSchemaForm<DataItem>
        title={!editValues?.id ? '新增分类' : '编辑分类'}
        formRef={formRef}
        width={600}
        open={open}
        onOpenChange={(b) => {
          !b && closeForm(b);
        }}
        layoutType={'ModalForm'}
        labelCol={{ span: 6 }}
        wrapperCol={{ span: 14 }}
        // grid={true}
        layout="horizontal"
        onFinish={submit}
        columns={formConfig(state?.enumList)}
        loading={bookCategoryEdit?.loading || bookCategoryAdd?.loading}
      />
    </PageContainer>
  );
};
export default Page;
