import { EditOutlined } from '@ant-design/icons';
import { ProColumns } from '@ant-design/pro-components';
import { Button, Input, Popconfirm, Space } from 'antd';
import { useState } from 'react';

export const columns = (params: {
  sort: (params: { id: any; sortNum: any }) => void;
  edit: (params: any) => void;
  del: (id: any) => void;
  enumList?: { [key: string]: any };
}): ProColumns<any>[] => {
  let { edit, del, enumList, sort } = params;
  return [
    {
      title: 'ID',
      dataIndex: 'id',
      key: 'id',
      align: 'center',
      width: 70,
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '分类名称',
      dataIndex: 'name',
      key: 'name',
      align: 'center',
      width: 70,
      ellipsis: true,
    },
    {
      title: '所属频道',
      dataIndex: 'workDirection',
      key: 'workDirection',
      align: 'center',
      width: 80,
      ellipsis: true,
      valueEnum: () => {
        let arr = enumList?.WORK_DIRECTION?.values;
        return arr
          ? new Map(
              [{ value: '', description: '全部' }, ...arr]?.map(({ value, description }: any) => [
                value,
                description,
              ]),
            )
          : {};
      },
    },
    {
      title: '排序',
      dataIndex: 'sortNum',
      key: 'sortNum',
      width: 80,
      align: 'center',
      ellipsis: true,
      hideInSearch: true,
      render: (text, record, _, action) => {
        function Page({ sortNum }: any) {
          const [value, setValue] = useState(sortNum);
          return (
            <Popconfirm
              title={
                <Input
                  addonBefore="移动到第"
                  addonAfter="位"
                  style={{ width: 180 }}
                  value={value}
                  onChange={(e) => {
                    let v = e.target.value;
                    if (!v) {
                      v = '0';
                    }
                    let ok = /^\d+$/.test(v);
                    if (ok) {
                      setValue(Number(v));
                    }
                  }}
                />
              }
              onConfirm={() => {
                sort({ id: record.id, sortNum: value });
              }}
              onCancel={() => {
                setValue(sortNum);
              }}
              icon={false}
            >
              <Button type="link">
                {text}
                <EditOutlined />
              </Button>
            </Popconfirm>
          );
        }
        return <Page sortNum={record.sortNum} />;
      },
    },
    {
      title: '操作',
      dataIndex: 'option',
      key: 'option',
      width: 160,
      align: 'center',
      className: 'table_fixed',
      hideInSearch: true,
      render: (a: any, b: any, _, action) => {
        return (
          <Space>
            <Button
              onClick={() => {
                edit(b);
              }}
              type="link"
            >
              编辑
            </Button>
            <Popconfirm
              title={
                <div>
                  确定要删除<span style={{ color: 'red' }}>{b.name}</span>分类?
                </div>
              }
              onConfirm={() => {
                del(b.id);
              }}
            >
              <a style={{ color: 'red', cursor: 'pointer' }}>删除</a>
            </Popconfirm>
          </Space>
        );
      },
    },
  ];
};
