import { ProColumns } from '@ant-design/pro-components';
import { Badge, Button, Popconfirm, Space, Switch } from 'antd';

export const columns = (props: {
  del: (id: any) => void;
  edit: (b: boolean, v: any) => void;
  setEditValues: (v: any) => void;
}): ProColumns<any>[] => {
  let { del, edit, setEditValues } = props;
  return [
    {
      title: 'ID',
      dataIndex: 'id',
      key: 'id',
      align: 'center',
      width: 70,
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '分销公司名称',
      dataIndex: 'companyName',
      key: 'companyName',
      align: 'center',
      width: 70,
      ellipsis: true,
    },
    {
      title: '分销公司描述',
      dataIndex: 'companyDesc',
      key: 'companyDesc',
      align: 'center',
      width: 80,
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '分销公司地址',
      dataIndex: 'companyAddress',
      key: 'companyAddress',
      width: 80,
      ellipsis: true,
      align: 'center',
      hideInSearch: true,
    },
    {
      title: '联系人姓名',
      dataIndex: 'contactName',
      key: 'contactName',
      width: 80,
      align: 'center',
      ellipsis: true,
    },
    {
      title: '联系人电话',
      dataIndex: 'contactPhone',
      key: 'contactPhone',
      width: 80,
      align: 'center',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '联系人邮箱',
      dataIndex: 'contactEmail',
      key: 'contactEmail',
      width: 80,
      align: 'center',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '备注',
      dataIndex: 'remark',
      key: 'remark',
      width: 80,
      align: 'center',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '操作',
      dataIndex: 'cz',
      key: 'cz',
      width: 160,
      fixed: 'right',
      align: 'center',
      hideInSearch: true,
      render: (a, b) => {
        return (
          <Space>
            <Button
              onClick={() => {
                edit(true, b);
              }}
              type="link"
              size="small"
            >
              编辑
            </Button>
            <Popconfirm
              title={
                <div>
                  确定要删除<span style={{ color: 'red' }}>{b.companyName}</span>分销商?
                </div>
              }
              onConfirm={() => {
                del(b.id);
              }}
            >
              <Button type="link" size="small" danger>
                删除
              </Button>
            </Popconfirm>
            <Button
              onClick={() => {
                setEditValues(b);
              }}
              type="link"
              size="small"
            >
              账号管理
            </Button>
          </Space>
        );
      },
    },
  ];
};

export const itemColumns = (props: {
  del: (id: any) => void;
  closeForm: (b: boolean, v: any) => void;
  stateUpdata: (id: any, ck: boolean) => Promise<any>;
}): ProColumns<any>[] => {
  let { del, closeForm, stateUpdata } = props;
  return [
    {
      title: 'ID',
      dataIndex: 'id',
      key: 'id',
      align: 'center',
      width: 70,
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '分销商名称',
      dataIndex: 'distributorName',
      key: 'distributorName',
      align: 'center',
      width: 70,
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '账号昵称',
      dataIndex: 'nickname',
      key: 'nickname',
      align: 'center',
      width: 80,
      ellipsis: true,
    },
    {
      title: '子账号',
      dataIndex: 'subDistributorAccountList',
      key: 'subDistributorAccountList',
      align: 'center',
      width: 80,
      ellipsis: true,
      hideInSearch: true,
      render(dom, entity, index, action, schema) {
        return entity?.subDistributorAccountList
          ?.map((item: { nickname: any }) => item.nickname)
          ?.join();
      },
    },
    {
      title: '手机号',
      dataIndex: 'phoneNum',
      key: 'phoneNum',
      width: 80,
      ellipsis: true,
      align: 'center',
    },
    {
      title: '备注',
      dataIndex: 'remark',
      key: 'remark',
      width: 80,
      align: 'center',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '状态',
      dataIndex: 'enabled',
      key: 'enabled',
      width: 80,
      align: 'center',
      ellipsis: true,
      hideInSearch: true,
      render: (a: any, b: any) => {
        return (
          <Switch
            checkedChildren="正常"
            unCheckedChildren="停用"
            checked={b.enabled}
            onChange={(ck) => {
              stateUpdata(b.id, ck);
            }}
          />
        );
      },
    },
    {
      title: '是否为管理员',
      dataIndex: 'manageAccount',
      key: 'manageAccount',
      width: 80,
      align: 'center',
      ellipsis: true,
      hideInSearch: true,
      valueEnum:{true:{text:<Badge status='success' text="是" />},false:{text:<Badge status='default' text="否" />}}
    },
    {
      title: '操作',
      dataIndex: 'cz',
      key: 'cz',
      width: 160,
      fixed: 'right',
      align: 'center',
      hideInSearch: true,
      render: (a: any, b: any) => {
        return (
          <Space>
            <Button
              onClick={() => {
                closeForm(true, b);
              }}
              type="link"
              size="small"
            >
              编辑
            </Button>
            <Popconfirm
              title={
                <div>
                  确定要删除<span style={{ color: 'red' }}>{b.nickname}</span>账号?
                </div>
              }
              onConfirm={() => {
                del(b.id);
              }}
            >
              <Button type="link" size="small" danger>
                删除
              </Button>
            </Popconfirm>
          </Space>
        );
      },
    },
  ];
};
